This project provides support for easy integration/acceptance testing of
[nginx](https://nginx.org/) configuration using TypeScript or
JavaScript, primarily for testing [njs](https://nginx.org/en/docs/njs/)
(NGINX JavaScript) scripts.

It’s supported and tested on Linux, macOS and Windows. Nginx binaries
are provided by project
[nginx-binaries](https://github.com/jirutka/nginx-binaries) for any
Linux \[1\] (x86\_64, aarch64, armv7, ppc64le), macOS (x86\_64) and
Windows (x86\_64).

TODO: Add more information.

## Installation

``` sh
# using npm:
npm install --save-dev nginx-testing
# or using yarn:
yarn add --dev nginx-testing
```

## Examples

### Nginx Runner

***example.test.ts:*.**

``` ts
import { strict as assert } from 'assert'
import { after, afterEach, before, beforeEach, test } from 'mocha'
import { startNginx, NginxServer } from 'nginx-testing'
import fetch from 'node-fetch'

let nginx: NginxServer

before(async () => {
  nginx = await startNginx({ version: '1.18.x', configPath: './nginx.conf' })
})

after(async () => {
  await nginx.stop()
})

beforeEach(async () => {
  // Consume logs (i.e. clean them before the test).
  await ngx.readAccessLog()
  await ngx.readErrorLog()
})

afterEach(async function () {
  // Print logs if the test failed.
  if (this.currentTest?.state === 'failed') {
    console.error('Access log:\n' + await ngx.readAccessLog())
    console.error('Error log:\n' + await ngx.readErrorLog())
  }
})

test('GET / results in HTTP 200', async () => {
  const resp = await fetch(`http://localhost:${nginx.port}/`)
  assert.equal(resp.status, 200)
})
```

***nginx.conf:*.**

``` nginx
events {
}
http {
  server {
    listen localhost:__PORT__;

    location / {
      return 200 "OK";
    }
  }
}
```

## License

This project is licensed under [MIT
License](http://opensource.org/licenses/MIT/).

1.  nginx binaries are built as standalone static executables, so they
    works on every Linux system regardless of used libc.
